#
# spec file for package xonsh
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           xonsh
Version:        0.6.2
Release:        bp156.3.46
Summary:        A general purpose, Python-ish shell
License:        BSD-3-Clause AND BSD-2-Clause
Group:          Development/Languages/Python
Url:            https://xonsh.org
Source:         https://github.com/xonsh/xonsh/archive/%{version}.tar.gz
# SECTION docs
BuildRequires:  python3-Sphinx
BuildRequires:  python3-numpydoc
# /SECTIOn
BuildRequires:  fdupes
BuildRequires:  python3-devel >= 3.4
BuildRequires:  python3-setuptools
Recommends:     python3-Pygments
Recommends:     python3-distro
Recommends:     python3-ply
Recommends:     python3-prompt_toolkit
Recommends:     python3-setproctitle
Suggests:       %{name}-doc
Provides:       python3-xonsh = %{version}
Obsoletes:      python3-xonsh < %{version}
BuildArch:      noarch

%package -n %{name}-doc
Summary:        Documentation files for %name
Group:          Documentation/HTML

%description
xonsh is a Python-ish, BASHwards-looking shell language and command prompt. The language is a superset of Python 3.4+ with additional shell primitives. xonsh (pronounced conch) is meant for the daily use of experts and novices alike.

%description -n %{name}-doc
HTML documentation on the API and examples for %name.

%prep
%setup -q -n xonsh-%{version}
sed -i '1s/^#!.*//' xonsh/xoreutils/_which.py xonsh/ply/example/classcalc/calc.py xonsh/ply/example/newclasscalc/calc.py xonsh/ply/example/yply/yply.py
sed -i '1s/^#!.*/#!\/usr\/bin\/python/' xonsh/ply/example/yply/yply.py

%build
python3 setup.py build
pushd docs
LANG=C.UTF-8 READTHEDOCS=True PYTHONPATH=.. make html
rm _build/html/.buildinfo
popd

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
%fdupes %{buildroot}

%files
%{python3_sitelib}/*
%{_bindir}/xonsh
%{_bindir}/xon.sh
%doc README.rst logo.txt CHANGELOG.rst
%doc xontrib
%doc xonsh/ply/example xonsh/ply/doc/*.html xonsh/ply/ANNOUNCE xonsh/ply/README.md xonsh/ply/CHANGES
%license license

%files -n %{name}-doc
%doc docs/_build/html

%changelog
* Sun Apr 29 2018 sebix+novell.com@sebix.at
- update to version 0.6.2:
  * Added:
  * Release tarballs now include licenses and minimal documentation for xonsh and ply
  * Wizard now has a FileInserter node that allows blocks to be inserted and replaced inside of a file. This adheres to conversion rules fordumping as provided on this node.
  * New xonsh.wizard.StateVisitor.flatten() method for flattening the current state.
  * Changed:
  * The xonsh startup wizard will only be triggered if no xonshrc files exist and the file ~/.local/config/xonsh/no-wizard is not present.
  * The xonfig wizard command will now run write out to the xonshrc file.
  * Wizard nodes Save and Load had their names changed to SaveJSON and LoadJSON.
  * Removed:
  * Static configuration is dead (config.json), long live run control (xonshrc)!
  * The following evironment variables have been removed as they are no longer needed: $LOADED_CONFIG and $XONSHCONFIG.
  * Many support functions for static configuration have also been removed.
  * Fixed:
  * Files starting with # are auto-escaped by TAB completion
* Sat Apr 14 2018 sebix+novell.com@sebix.at
- update to version 0.6.1:
  * Added:
  * Support for MSYS2.
  * New ``xonsh.main.setup()`` function for starting up xonsh in 3rd party
    packages.
  * Changed:
  * Updated CircleCI to use circle version 2.0
  * Replaced StopIteration with return in CommandPipeline.iterraw.
  * Xonsh run control now also looks for the XDG-compliant file
    ``~/.config/xonsh/rc.xsh`` at startup.
  * Fixed:
  * Clean out ``$LINES`` and ``$COLUMNS`` if set, preventing some programs from drawing weirdly
  * cat from xoreutils now outputs in configured encoding
  * Fixed hanging issue with pipelines whose middle processes exit before the
    first or last process.
  * Fixed issue where xonsh would deduplicate spaces from bash autocompletions.
  * Fixed failing redirections from stderr to stdout when the command
    being executed was a callable alias.
  * Ensure that the ``free_cwd`` contrib can only be active on pure Windows.
  * Made an exceptional case in ``iglobpath()`` more robust when Python globbing
    fails for due to strange scrandir issue.
  * Unexpected process suspension on Cygwin and MSYS2.
  * ``$XONSH_APPEND_NEWLINE`` will now default to True when in interactive mode.
  * Fixed issue with uncalled lambdas being run in subproc mode.
  * Lambda nodes not have proper line and column numbers in AST.
  * Properly throw ``SyntaxError`` when no kwargs are defined
    in a kwarg-only function. This used to throw a
    ``TypeError: 'NoneType' object is not iterable``.
  * Addressed issue where encoding and errors were None when teeing output.
  * Commands like ``git c`` would complete to ``git 'checkout '`` because git adds an extra space
    to the end of the completion, which was being captured in the completion. Xonsh now fixes the git issue
    while retaining all whitespace when there is other internal whitespace.
* Fri Dec  8 2017 sebix+novell.com@sebix.at
- change source URL to github as docs are included
- add xonsh-doc package with HTML documentation
* Thu Dec  7 2017 sebix+novell.com@sebix.at
- run spec-cleaner
- Add python3-ply as recommendation. It's included as fallback but defaults to the distribution's library.
* Mon Dec  4 2017 sebix+novell.com@sebix.at
- update to version 0.6.0
  * Fixed:
  * Fixed a bug on py34 where os.scandir was used by accident.
  * Line continuations (\\) is subproc mode will no longer consume the surrounding whitespace.
  * Fixed a bug if foreign_shell name was not written in lower case in the static configuration file config.json
  * Fixed issue with foregrounding jobs that were started in the background.
  * Fixed that Ctrl-C crashes xonsh after running an invalid command.
  * Fixed an potential ProcessLookupError issue, see #2288.
* Sat Jul 22 2017 sebix+novell.com@sebix.at
- update to version 0.5.12
  * Fixed release.xsh to prevent it from dirtying the repo on release and
  leading to an unwanted .dev suffix on the version number
- update to version 0.5.11
  * release.xsh creates a github release with the merged news entries as the
  release body
  * xonfig now displays the proper value for "on linux"
- update to version 0.5.10
  * Added xclip and repo to default threadable predictors (Issues #2355 and #2348)
  * Pretty printing of the $PATH variable
  * Add "fzf-widgets" xontrib which provides fuzzy search productivity widgets with on custom keybindings to xontrib list.
  * Fixed the --rc option so it now runs xonsh with the specified rc file
  * @$ operator now functions properly when returned command is an alias
  * Correct line continuation would not work on Windows if the line continuations were used in the xonshrc file.
  * Fix echo command from xoreutils.
- update to version 0.5.9
  * Add Alt . keybinding to bashisms-xontrib to insert last argument of
  previous command into current buffer
  * Added missing ensurers to make sure that bool env_vars are bools and
  * int env_vars are integers:
  * DIRSTACK_SIZE
  * EXPAND_ENV_VARS
  * PUSHD_MINUS
  * PUSHD_SILENT
  * SUGGEST_COMMANDS
  * SUGGEST_MAX_NUM
  * SUGGEST_THRESHOLD
* Thu Mar  9 2017 sebix+novell.com@sebix.at
- version 0.5.8
* Wed Feb  1 2017 sebix+novell.com@sebix.at
- version 0.5.3
- Added:
  * Tab completion xontrib for python applications based on click framework.
  * Added on_transform_command event for pre-processing that macros can't handle.
  * Autodetection of backgroundability by binary analysis on POSIX.
  * New argument expand_user=True to tools.expand_path.
  * New $COMPLETION_QUERY_LIMIT environment variable for setting the number of completions above which the user will be asked if they wish to see the potential completions.
  * Users may now redirect stdout to stderr in subprocess mode.
- Changed:
  * The Block and Functor context managers from xonsh.contexts have been rewritten to use xonsh's macro capabilities. You must now enter these via the with! statement, e.g. with! Block(): pass.
  * The distributed xontrib now needs to use the with! statement, since it relies on Functor.
  * telnet has been flagged as unthreadable.
  * When $DYNAMIC_CWD_ELISION_CHAR is non empty and the last dir of cwd is too long and shortened, the elision char is added at the end.
  * pygments is no longer a strict dependency of the prompt_toolkit backend. If pygments is not installed, the PTK backend will use the default ansi color settings from the terminal. Syntax highlighting requires that pygments is installed.
  * Events are now keyword arguments only
  * Restored on_precommand to its original signature.
  * Move built_ins.expand_path to tools.expand_path.
  * Rename tools.expandpath to tools._expandpath.
  * Added gvim command to unthreadable predictors.
  * The source alias now passes $ARGS down to file it is sourcing.
- Removed:
  * XonshBlockError has been removed, since it no longer serves a purpose.
- Fixed:
  * PopenThread will now re-issue SIGINT to the main thread when it is recieved.
  * Fixed an issue that using sqlite history backend does not kill unfinished jobs when quitting xonsh with a second "exit".
  * Fixed an issue that xonsh would fail over to external shells when running .xsh script which raises exceptions.
  * Fixed an issue with openpty() returning non-unix line endings in its buffer. This was causing git and ssh to fail when xonsh was used as the login shell on the server. See https://mail.python.org/pipermail/python-list/2013-June/650460.html for more details.
  * Restored the ability to ^Z and fg processes on posix platforms.
  * CommandPipelines were not gauranteeded to have been ended when the return code was requested. This has been fixed.
  * Introduce path expansion in is_writable_file to fix $XONSH_TRACEBACK_LOGFILE=~/xonsh.log.
  * Backgrounding a running process (^Z) now restores ECHO mode to the terminal in cases where the subprocess doesn't properly restore itself. A major instance of this behaviour is Python's interactive interpreter.
  * Readline backend would not ask the user to confirm the printing of completion options if they numbered above a certain value. Instead they would be dumped to the screen. This has been fixed.
  * Jupyter kernel was no longer properly running subprocess commands. This has been fixed.
  * The filename is applied to the target of the source alias, providing better tracebacks.
* Thu Jan  5 2017 sebix+novell.com@sebix.at
- version 0.5.2
- Added:
  * Added weechat to default predictors
  * $DYNAMIC_CWD_ELISION_CHAR environment variable to control how a shortened path is displayed.
- Changed:
  * _ret_code function of prompt_ret_code xontrib return now None when return code is 0 instead of empty string allowing more customization of prompt format.
- Fixed:
  * Minor Python completer token counting bug fix.
  * multiline syntax error in PTK shell due to buffer not being reset
  * Segfaults and other early exit signals are now reported correctly, again.
* Wed Dec 21 2016 sebix+novell.com@sebix.at
- update to 0.5.1
* Sun Dec 18 2016 sebix+novell.com@sebix.at
- update to 0.4.7
- fix license
* Sat Aug 27 2016 sebix+novell.com@sebix.at
- initial package for xonsh
